<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=sk
// ** ne pas modifier le fichier **

return [

	// I
	'images_description' => 'Filtre na transformáciu obrázkov a farieb',
	'images_slogan' => 'Filtre na transformáciu obrázkov a farieb',
];
